@@ -60,6 +60,13 @@ def start_safari():
     windmill.settings['controllers'].append(controller)
     return controller
     
+def start_chrome():
+    """Start the Crhome web browser configured for windmill"""
+    controller = windmill.browser.get_chrome_controller()
+    controller.start()
+    windmill.settings['controllers'].append(controller)
+    return controller
+    
 def load_json_test_file(filename):
     """Run the json test files passed to this function"""
     test_strings = re.compile("\{.*\}").findall(open(filename, 'r').read())
@@ -98,13 +105,15 @@ def do_test(filename, load=False, threaded=True):
     def run_functest():
         if load:
             functest.registry['browser_debugging'] = "True"
-            xmlrpc_client.add_command({'method':'commands.setOptions', 'params':{'runTests':False, 'priority':'normal'}})
+            xmlrpc_client.add_command({'method':'commands.setOptions', 
+                                       'params':{'runTests':False, 'priority':'normal'}})
         functest.global_settings.test_filter = filter_string
         from windmill.authoring import WindmillFunctestRunner, post_collector
         functest.collector.Collector.post_collection_functions.append(post_collector)
         functest.run_framework(test_args=[module_name], test_runner=WindmillFunctestRunner())
         if load:
-            xmlrpc_client.add_command({'method':'commands.setOptions', 'params':{'runTests':True, 'priority':'normal'}})
+            xmlrpc_client.add_command({'method':'commands.setOptions', 
+                                       'params':{'runTests':True, 'priority':'normal'}})
         windmill.block_exit = False
     
     if module_name is not None and threaded:    
@@ -130,6 +139,7 @@ load_test.__name__ = 'load_test'
 load_test.__doc__ = "Load the test file or directory passed to this function"   
 
 def run_js_tests(js_dir, test_filter=None, phase=None):
+    js_dir = os.path.abspath(os.path.expanduser(js_dir))
     from wsgi_fileserver import WSGIFileServerApplication
     application = WSGIFileServerApplication(root_path=os.path.abspath(js_dir), mount_point='/windmill-jstest/')
     from windmill.server import wsgi
