@@ -1,15 +1,9 @@
 var elementslib = new function(){
-  //base vars
-  var win = opener;
+ 
   var domNode = null;
   //keep track of the locators we cant get via the domNode
   var locators = {};
   
-  this.setWindow = function(windowObj){
-    win = windowObj;
-    return win;
-  };
-  
   //element constructor
   this.Element = function(node){
     if (node){ domNode = node;}
@@ -56,9 +50,14 @@ var elementslib = new function(){
     domNode = nodeSearch(nodeByValue, s);
     return returnOrThrow(s);
   };
-  this.Element.XPATH = function(s, xb){
+  this.Element.LABEL = function(s){
+    locators.labelname = s;
+    domNode = nodeSearch(nodeByLabel, s);
+    return returnOrThrow(s);
+  };
+  this.Element.XPATH = function(s){
     locators.xpath = s;
-    domNode = nodeSearch(nodeByXPath, s, xb);
+    domNode = nodeSearch(nodeByXPath, s, document);
     //do the lookup, then set the domNode to the result
     return returnOrThrow(s);
   };
@@ -78,37 +77,37 @@ var elementslib = new function(){
   
   //do the recursive search
   //takes the function for resolving nodes and the string
-  var nodeSearch = function(func, s){
+  var nodeSearch = function(func, s, doc){
     var e = null;
-
     //inline function to recursively find the element in the DOM, cross frame.
-    var recurse = function(w, func, s){
+    var recurse = function(w, func, s, doc){
      //do the lookup in the current window
-     try{ element = func.call(w, s);}
+     try{ element = func.call(w, s, doc);}
      catch(err){ element = null; }
      
       if (!element){
         var fc = w.frames.length;
         var fa = w.frames;   
         for (var i=0;i<fc;i++){
-          recurse(fa[i], func, s); 
+          recurse(fa[i], func, s, doc); 
         }
      }
      else { e = element; }
     };
     
     //IE cross window problems require you to talk directly to opener
-     try{ element = func.call(opener, s);}
+     try{ element = func.call(windmill.testWin(), s, doc);}
      catch(err){ element = null; }
      if (!element){
-       for (var i=0;i<opener.frames.length;i++){
-         try { element = func.call(opener.frames[i], s); }
+       for (var i=0;i<windmill.testWin().frames.length;i++){
+         try { element = func.call(windmill.testWin().frames[i], s, doc); }
          catch(err){ element = null; }
        }
      }
-     
+        
     if (element){ return element; }
-    recurse(win, func, s);
+    recurse(windmill.testWin(), func, s, doc);
+    recurse(windmill.baseTestWindow, func, s, doc);
     
     return e;
   }
@@ -162,7 +161,7 @@ var elementslib = new function(){
     for (var i = 0; i < links.length; i++) {
       var el = links[i];
       var linkText = getText(el);
-      if (linkText.indexOf(s) != -1) {
+      if (linkText.trim() == s.trim()) {
         return el;
       }
     }
@@ -196,6 +195,18 @@ var elementslib = new function(){
       var cn = s;
       var idx = 0;
     }
+    if (!this.document.getElementsByClassName){
+      this.document.getElementsByClassName = function(cl) {
+        var retnode = [];
+        var myclass = new RegExp('\\b'+cl+'\\b');
+        var elem = this.getElementsByTagName('*');
+        for (var i = 0; i < elem.length; i++) {
+        var classes = elem[i].className;
+        if (myclass.test(classes)) retnode.push(elem[i]);
+        }
+        return retnode;
+      };
+    }
     return this.document.getElementsByClassName(cn)[idx];
   };
   
@@ -225,31 +236,42 @@ var elementslib = new function(){
     return node[0];
   };
   
-  //Lookup with xpath
-  var nodeByXPath = function (xpath, xb) {
-    var nsResolver = function (prefix) {
-      if (prefix == 'html' || prefix == 'xhtml' || prefix == 'x') {
-        return 'http://www.w3.org/1999/xhtml';
-      } else if (prefix == 'mathml') {
-        return 'http://www.w3.org/1998/Math/MathML';
-      } else {
-        throw new Error("Unknown namespace: " + prefix + ".");
+  var nodeByLabel = function (s) { //search nodes by name
+    //sometimes the win object won't have this object
+    var labels = this.document.getElementsByTagName('label');
+    var node = null;
+    var label = null;
+
+    //Find the label from all labels on the page
+    for (i = 0;i < labels.length; i++){
+      if (labels[i].innerHTML.trim() == s.trim()){
+        label = labels[i];
       }
     }
-    // Use document.evaluate() if it's available
-    if (this.document.evaluate && !xb) {
-      return this.document.evaluate(xpath, this.document, nsResolver, 0, null).iterateNext();
+    
+    //If we have a label, use its for attrib to get the id of the input
+    if (label != null){
+      if (windmill.browser.isIE){
+        var iid = label.getAttribute('htmlFor');
+      }
+      else {
+        var iid = label.getAttribute('for');
+      }
+      node = this.document.getElementById(iid);
     }
-    
-    xpath = xpath.replace(/\[@.*?\]/g, '');
-    var expr = xpathParse(xpath.toUpperCase());
-    var xpathResult = expr.evaluate(new ExprContext(this.document));
-    
-    if (xpathResult && xpathResult.value) {
-      return xpathResult.value[0];
-    } 
-    
-    return null;
+    //either return the found input node, or null
+    return node;
   };
   
+  //Lookup with xpath
+  var nodeByXPath = function (xpath, doc) {
+    //if there is built in document.evaluate
+    if (this.document.evaluate){
+      return this.document.evaluate(xpath, this.document, null, 0, null).iterateNext();
+    }
+    //Else pass the IDE window.document that has a document.evaluate
+    else {
+      return doc.evaluate(xpath, this.document, null, 0, null).iterateNext();
+    }
+  };
 };
\ No newline at end of file
