@@ -54,37 +54,32 @@ var lookupNode = function (paramObject, throwErr){
   if(typeof paramObject.jsid != "undefined") {
     //Here if the user hasn't specified the test window scope
     //we use the default and prepend it, else we eval whatever js they passed
-    var jsid; 
-    if ((paramObject.jsid.indexOf('windmill.testWindow') != -1) || (paramObject.jsid.indexOf('_w') != -1)){
-      eval ("jsid=" + paramObject.jsid + ";");
-    }
-    else{
-      eval ("jsid=" + this._getWindowStr() + '.' +paramObject.jsid + ";");
-    }
-      s = 'Looking up jsid '+ jsid;
-      element = elementslib.Element.ID(paramObject.id);
+    var jsid = windmill.testWin().eval(paramObject.jsid);
+    //eval("jsid=" + paramObject.jsid + ";");
+    s = 'Looking up jsid '+ jsid;
+    element = elementslib.Element.ID(jsid);
   }
   //if name was passed
   if(typeof paramObject.name != "undefined") {
     s = 'Looking up name '+ paramObject.name;
     element = elementslib.Element.NAME(paramObject.name);
   }
-  //if name was passed
+  //if value was passed
   if(typeof paramObject.value != "undefined") {
-    s = 'Looking up value '+ unescape(paramObject.value);
+    s = 'Looking up value '+ paramObject.value;
     element = elementslib.Element.VALUE(paramObject.value);
   }
-  //if name was passed
+  //if classname was passed
   if(typeof paramObject.classname != "undefined") {
     s = 'Looking up classname '+ paramObject.classname;
     element = elementslib.Element.CLASSNAME(paramObject.classname);
   }
-  //if name was passed
+  //if tagname was passed
   if(typeof paramObject.tagname != "undefined") {
     s = 'Looking up tagname '+ paramObject.tagname;
     element = elementslib.Element.TAGNAME(paramObject.tagname);
   }
-  //if name was passed
+  //if label was passed
   if(typeof paramObject.label != "undefined") {
     s = 'Looking up label '+ paramObject.label;
     element = elementslib.Element.LABEL(paramObject.label);
@@ -128,7 +123,7 @@ var sendCommandResult = function(status, uuid, result){
 	var jsonObject = new jsonCall('1.1', 'command_result');
 	var params_obj = {"status":status, "uuid":uuid, "result":result};
 	jsonObject.params = params_obj;
-	var jsonString = fleegix.json.serialize(jsonObject)
+	var jsonString = JSON.stringify(jsonObject)
 
 	var resp = function(str){ return true; }
     
@@ -611,4 +606,20 @@ function removeHTMLTags(str){
  		var strTagStrippedText = str.replace(/<\/?[^>]+(>|$)/g, "");
  		strTagStrippedText = strTagStrippedText.replace(/&nbsp;/g,"");
 	return strTagStrippedText;
-}
\ No newline at end of file
+};
+
+var getParentWindow = function(node){
+  var ownerDoc = node.ownerDocument;
+  var win = null;
+  if (ownerDoc.defaultView){
+    win = ownerDoc.defaultView;
+  }
+  else {
+    win = ownerDoc.parentWindow;
+  }
+  if (win == null){
+    win = windmill.testWin();
+  }
+  
+  return win;
+};
\ No newline at end of file
