@@ -23,7 +23,9 @@ windmill.ui.assertexplorer = new function() {
   }
 
   //Reset the border to what it was before the mouse over
-  this.resetBorder = function(e) { e.target.style.border = ''; }
+  this.resetBorder = function(e) { 
+    e.target.style[windmill.ui.hilightProp] = '';
+  }
 
     //Display the id in the remote
     this.setIdInRemote = function(e) {
@@ -79,9 +81,9 @@ windmill.ui.assertexplorer = new function() {
       
        //trying to keep old borders from getting left all over the page
        if (windmill.ui.assertexplorer.currElem){
-         windmill.ui.assertexplorer.currElem.style.border = "";
+         windmill.ui.assertexplorer.currElem.style[windmill.ui.hilightProp] = "";
        }
-       e.target.style.border = windmill.ui.borderHilight;
+       e.target.style[windmill.ui.hilightProp] = windmill.ui.borderHilight;
        windmill.ui.assertexplorer.currElem = e.target;
     }
 
@@ -159,10 +161,10 @@ windmill.ui.assertexplorer = new function() {
         $('assertx').src = 'img/axoff.png';
         $('domExp').style.display = 'block';
         $('domExp').innerHTML = '';
-        this.axRecursiveBind(opener);
+        this.axRecursiveBind(windmill.testWin());
       }
       catch(error) {
-        windmill.ui.results.writeResult('Binding to windows and iframes, '+error +'.. binding all others.');
+        windmill.err('Binding to windows and iframes, '+error +'.. binding all others.');
         $('assertx').src = 'img/axon.png';
         this.exploreState = false;
       }
@@ -178,10 +180,10 @@ windmill.ui.assertexplorer = new function() {
         $('assertx').src = 'img/axon.png';
         $('domExp').style.visibility = 'hidden';
         $('domExp').innerHTML = '';
-        this.axRecursiveUnBind(opener);
+        this.axRecursiveUnBind(windmill.testWin());
       }
       catch(error) {
-        windmill.ui.results.writeResult('Binding to windows and iframes, '+error +'.. binding all others.');
+        windmill.err('Binding to windows and iframes, '+error +'.. binding all others.');
       }
     }
 
@@ -204,7 +206,7 @@ windmill.ui.assertexplorer = new function() {
           this.axRecursiveBind(iframeArray[i]);
         }
         catch(error) {
-          windmill.ui.results.writeResult('Binding to windows and iframes, '+error +'.. binding all others.');
+          windmill.err('Binding to windows and iframes, '+error +'.. binding all others.');
         }
       }
     }
@@ -226,7 +228,7 @@ windmill.ui.assertexplorer = new function() {
 
         }
         catch(error) {
-          windmill.ui.results.writeResult('Binding to windows and iframes, '+error +'.. binding all others.');
+          windmill.err('Binding to windows and iframes, '+error +'.. binding all others.');
         }
       }
     }
