@@ -67,9 +67,9 @@ windmill.registry.methods['waits.forPageLoad']    = {'locator': false, 'option':
 windmill.registry.methods['-- Other --']        = {'locator': false, 'option': false, 'section': true};
 windmill.registry.methods['triggerEvent']    = {'locator': true, 'option': 'option' };
 windmill.registry.methods['closeWindow']   = {'locator': false, 'option': false};
-windmill.registry.methods['complex']            = {'locator': false, 'option': false };
-windmill.registry.methods['execJsInTestWindow']   = {'locator': false, 'option': 'js' };
-windmill.registry.methods['execIDEJS']            = {'locator': false, 'option': 'js' };
+windmill.registry.methods['complex']        = {'locator': false, 'option': false };
+windmill.registry.methods['execJS']         = {'locator': false, 'option': 'js' };
+windmill.registry.methods['execIDEJS']      = {'locator': false, 'option': 'js' };
 windmill.registry.methods['revertWindow']   = {'locator': false, 'option': false};
 windmill.registry.methods['reWriteAlert']       = {'locator': false, 'option': false };
 windmill.registry.methods['setPromptDefault']       = {'locator': false, 'option': 'val' };
@@ -83,6 +83,7 @@ windmill.registry.methods['storeVarFromIDEJS']     = {'locator': false, 'option'
 windmill.registry.methods['storeVarFromLocAttrib']     = {'locator': true, 'option': 'options' };
 windmill.registry.methods['-- Asserts --']        = {'locator': false, 'option': false, 'section': true};
 windmill.registry.methods['asserts.assertJS']    = {'locator': false, 'option': 'js' };
+windmill.registry.methods['asserts.assertIDEJS']    = {'locator': false, 'option': 'js' };
 windmill.registry.methods['asserts.assertElemJS']    = {'locator': true, 'option': 'js' };
 windmill.registry.methods['asserts.assertProperty'] = {'locator': true, 'option': 'validator' };
 windmill.registry.methods['asserts.assertText']     = {'locator': true, 'option': 'validator' };
